@@ -1,3 +1,25 @@
+# (The MIT License)
+#
+# Copyright (c) 2013 Kura
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the 'Software'), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 """blackhole.data - Provides SMTP response codes and methods
 for returning the correct response code.
 
@@ -14,9 +36,9 @@ from tornado.options import options
 
 
 RESPONSES = {
-    '220': "OK, ready",
+    '220': "OK",
     '221': "Thank you for speaking to me",
-    '250': "OK, done",
+    '250': "OK",
     '251': "OK, user not local, will forward",
     '252': "OK, cannot VRFY user but will attempt delivery",
     '253': "OK, messages pending",
@@ -46,7 +68,7 @@ RESPONSES = {
     '571': "Blocked",
 }
 
-ACCEPT_RESPONSES = ('250', '251', '252', '253')
+ACCEPT_RESPONSES = ('250',)
 
 # Bounce responses
 BOUNCE_RESPONSES = ('421', '431', '450', '451', '452',
@@ -63,7 +85,7 @@ UNAVAILABLE_RESPONSES = ('421',)
 # Random responses
 RANDOM_RESPONSES = ACCEPT_RESPONSES + BOUNCE_RESPONSES
 
-EHLO_RESPONSES = ("250-2.5.0 OK, done", "250-SIZE 512000",
+EHLO_RESPONSES = ("250-OK", "250-SIZE 512000",
                   "250-VRFY", "250-STARTTLS",
                   "250-ENHANCEDSTATUSCODES", "250-8BITMIME",
                   "250 DSN")
@@ -123,5 +145,4 @@ def response_message(response):
     response = str(response)
     message = RESPONSES[response]
     smtp_code = response
-    esmtp_code = ".".join(list(response))
-    return "%s %s %s\n" % (smtp_code, esmtp_code, message)
+    return "%s %s\r\n" % (smtp_code, message)
